==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/sax/GnomeSAXParser.h <==
// class gnu.xml.libxmlj.sax.GnomeSAXParser

// class file dependencies
// @dep_class d8d939b31115bd08 gnu_xml_libxmlj_sax_GnomeSAXParser
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8d3180c29ab6d2bd javax_xml_parsers_SAXParser

// header file dependencies
// @dep_header javax_xml_parsers_SAXParser

#include "javax/xml/parsers/SAXParser.h"

#ifndef _JC_gnu_xml_libxmlj_sax_GnomeSAXParser_H_
#define _JC_gnu_xml_libxmlj_sax_GnomeSAXParser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Parser$object;
struct _jc_org_xml_sax_XMLReader$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_refs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_nonrefs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$refs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$refs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$nonrefs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object;

typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vmethods	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtable	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtable;
typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$_init$668f2a347f627c06(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, jboolean, jboolean);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$getParser$5ccc935c216d978f(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$getProperty$ad67146a826fdaf8(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$getXMLReader$2d78777e030cb408(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *);
extern jboolean _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$isNamespaceAware$a8b751f0cad64593(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *);
extern jboolean _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$isValidating$c40ecdd1e5e6c7a7(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *);
extern void _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$setProperty$a4769aed759cc4ba(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$getParser$5ccc935c216d978f;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$getProperty$ad67146a826fdaf8;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$getXMLReader$2d78777e030cb408;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$isNamespaceAware$a8b751f0cad64593;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$isValidating$c40ecdd1e5e6c7a7;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$setProperty$a4769aed759cc4ba;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vmethods {
	struct _jc_object	*(*getParser$5ccc935c216d978f)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *);
	struct _jc_java_lang_Object$object	*(*getProperty$ad67146a826fdaf8)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*getXMLReader$2d78777e030cb408)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *);
	jboolean	(*isNamespaceAware$a8b751f0cad64593)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *);
	jboolean	(*isValidating$c40ecdd1e5e6c7a7)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *);
	void	(*setProperty$a4769aed759cc4ba)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_SAXParser$vmethods	javax_xml_parsers_SAXParser;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vmethods	gnu_xml_libxmlj_sax_GnomeSAXParser;
};

// Vtype
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$refs {
    _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_refs	gnu_xml_libxmlj_sax_GnomeSAXParser;
    _jc_javax_xml_parsers_SAXParser$sub_refs	javax_xml_parsers_SAXParser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_nonrefs {
	jboolean	namespaceAware;
	jboolean	validating;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_SAXParser$sub_nonrefs	javax_xml_parsers_SAXParser;
    _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_nonrefs	gnu_xml_libxmlj_sax_GnomeSAXParser;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object {
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype	*vtype;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_sax_GnomeSAXParser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$class_object;

#endif	/* _JC_gnu_xml_libxmlj_sax_GnomeSAXParser_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/sax/GnomeSAXParser.h <==
// class gnu.xml.libxmlj.sax.GnomeSAXParser

// class file dependencies
// @dep_class d8d939b31115bd08 gnu_xml_libxmlj_sax_GnomeSAXParser
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8d3180c29ab6d2bd javax_xml_parsers_SAXParser

// header file dependencies
// @dep_header javax_xml_parsers_SAXParser

#include "javax/xml/parsers/SAXParser.h"

#ifndef _JC_gnu_xml_libxmlj_sax_GnomeSAXParser_H_
#define _JC_gnu_xml_libxmlj_sax_GnomeSAXParser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Parser$object;
struct _jc_org_xml_sax_XMLReader$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_refs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_nonrefs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$refs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$refs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$nonrefs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object;

typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vmethods	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtable	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtable;
typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$_init$668f2a347f627c06(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, jboolean, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$getParser$5ccc935c216d978f(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$getProperty$ad67146a826fdaf8(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$getXMLReader$2d78777e030cb408(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$isNamespaceAware$a8b751f0cad64593(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$isValidating$c40ecdd1e5e6c7a7(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method$setProperty$a4769aed759cc4ba(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$getParser$5ccc935c216d978f;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$getProperty$ad67146a826fdaf8;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$getXMLReader$2d78777e030cb408;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$isNamespaceAware$a8b751f0cad64593;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$isValidating$c40ecdd1e5e6c7a7;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$method_info$setProperty$a4769aed759cc4ba;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vmethods {
	struct _jc_object	*(*getParser$5ccc935c216d978f)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getProperty$ad67146a826fdaf8)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getXMLReader$2d78777e030cb408)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *) _JC_JCNI_ATTR;
	jboolean	(*isNamespaceAware$a8b751f0cad64593)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *) _JC_JCNI_ATTR;
	jboolean	(*isValidating$c40ecdd1e5e6c7a7)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *) _JC_JCNI_ATTR;
	void	(*setProperty$a4769aed759cc4ba)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_SAXParser$vmethods	javax_xml_parsers_SAXParser;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vmethods	gnu_xml_libxmlj_sax_GnomeSAXParser;
};

// Vtype
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$refs {
    _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_refs	gnu_xml_libxmlj_sax_GnomeSAXParser;
    _jc_javax_xml_parsers_SAXParser$sub_refs	javax_xml_parsers_SAXParser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_nonrefs {
	jboolean	namespaceAware;
	jboolean	validating;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_SAXParser$sub_nonrefs	javax_xml_parsers_SAXParser;
    _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$sub_nonrefs	gnu_xml_libxmlj_sax_GnomeSAXParser;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$object {
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype	*vtype;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParser$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$vtype _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_sax_GnomeSAXParser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_sax_GnomeSAXParser$class_object;

#endif	/* _JC_gnu_xml_libxmlj_sax_GnomeSAXParser_H_ */
